@@ -3,14 +3,13 @@
 module Mutations
   module MergeRequests
     class Base < BaseMutation
-      include Gitlab::Graphql::Authorize::AuthorizeResource
       include Mutations::ResolvesProject
 
       argument :project_path, GraphQL::ID_TYPE,
                required: true,
                description: "The project the merge request to mutate is in"
 
-      argument :iid, GraphQL::ID_TYPE,
+      argument :iid, GraphQL::STRING_TYPE,
                required: true,
                description: "The iid of the merge request to mutate"
 
