@@ -12,11 +12,16 @@ class Release < ApplicationRecord
 
   has_many :links, class_name: 'Releases::Link'
 
+  default_value_for :released_at, allows_nil: false do
+    Time.zone.now
+  end
+
   accepts_nested_attributes_for :links, allow_destroy: true
 
   validates :description, :project, :tag, presence: true
+  validates :name, presence: true, on: :create
 
-  scope :sorted, -> { order(created_at: :desc) }
+  scope :sorted, -> { order(released_at: :desc) }
 
   delegate :repository, to: :project
 
@@ -30,8 +35,11 @@ class Release < ApplicationRecord
     actual_tag.nil?
   end
 
-  def assets_count
-    links.count + sources.count
+  def assets_count(except: [])
+    links_count = links.count
+    sources_count = except.include?(:sources) ? 0 : sources.count
+
+    links_count + sources_count
   end
 
   def sources
@@ -40,6 +48,10 @@ class Release < ApplicationRecord
     end
   end
 
+  def upcoming_release?
+    released_at.present? && released_at > Time.zone.now
+  end
+
   private
 
   def actual_sha
