@@ -11,7 +11,7 @@ class EnvironmentStatusEntity < Grape::Entity
     project_environment_path(es.project, es.environment)
   end
 
-  expose :metrics_url, if: ->(*) { can_read_environment? && deployment.has_metrics? } do |es|
+  expose :metrics_url, if: ->(*) { can_read_environment? && has_metrics? } do |es|
     metrics_project_environment_deployment_path(es.project, es.environment, es.deployment)
   end
 
@@ -45,8 +45,8 @@ class EnvironmentStatusEntity < Grape::Entity
     object.environment
   end
 
-  def deployment
-    object.deployment
+  def has_metrics?
+    object.has_metrics?
   end
 
   def project
