@@ -34,14 +34,20 @@ class IssuableBaseService < BaseService
   end
 
   def filter_assignee(issuable)
-    return unless params[:assignee_id].present?
+    return if params[:assignee_ids].blank?
 
-    assignee_id = params[:assignee_id]
+    unless issuable.allows_multiple_assignees?
+      params[:assignee_ids] = params[:assignee_ids].first(1)
+    end
 
-    if assignee_id.to_s == IssuableFinder::NONE
-      params[:assignee_id] = ""
+    assignee_ids = params[:assignee_ids].select { |assignee_id| assignee_can_read?(issuable, assignee_id) }
+
+    if params[:assignee_ids].map(&:to_s) == [IssuableFinder::NONE]
+      params[:assignee_ids] = []
+    elsif assignee_ids.any?
+      params[:assignee_ids] = assignee_ids
     else
-      params.delete(:assignee_id) unless assignee_can_read?(issuable, assignee_id)
+      params.delete(:assignee_ids)
     end
   end
 
@@ -176,7 +182,7 @@ class IssuableBaseService < BaseService
     # To be overridden by subclasses
   end
 
-  def before_update(issuable)
+  def before_update(issuable, skip_spam_check: false)
     # To be overridden by subclasses
   end
 
@@ -199,7 +205,7 @@ class IssuableBaseService < BaseService
     end
 
     if issuable.changed? || params.present?
-      issuable.assign_attributes(params.merge(updated_by: current_user))
+      issuable.assign_attributes(params)
 
       if has_title_or_description_changed?(issuable)
         issuable.assign_attributes(last_edited_at: Time.now, last_edited_by: current_user)
@@ -207,11 +213,16 @@ class IssuableBaseService < BaseService
 
       before_update(issuable)
 
+      # Do not touch when saving the issuable if only changes position within a list. We should call
+      # this method at this point to capture all possible changes.
+      should_touch = update_timestamp?(issuable)
+
+      issuable.updated_by = current_user if should_touch
       # We have to perform this check before saving the issuable as Rails resets
       # the changed fields upon calling #save.
       update_project_counters = issuable.project && update_project_counter_caches?(issuable)
 
-      if issuable.with_transaction_returning_status { issuable.save }
+      if issuable.with_transaction_returning_status { issuable.save(touch: should_touch) }
         # We do not touch as it will affect a update on updated_at field
         ActiveRecord::Base.no_touching do
           Issuable::CommonSystemNotesService.new(project, current_user).execute(issuable, old_labels: old_associations[:labels])
@@ -246,7 +257,7 @@ class IssuableBaseService < BaseService
                                               last_edited_at: Time.now,
                                               last_edited_by: current_user))
 
-      before_update(issuable)
+      before_update(issuable, skip_spam_check: true)
 
       if issuable.with_transaction_returning_status { issuable.save }
         # We do not touch as it will affect a update on updated_at field
@@ -347,12 +358,13 @@ class IssuableBaseService < BaseService
         assignees: issuable.assignees.to_a
       }
     associations[:total_time_spent] = issuable.total_time_spent if issuable.respond_to?(:total_time_spent)
+    associations[:description] = issuable.description
 
     associations
   end
 
   def has_changes?(issuable, old_labels: [], old_assignees: [])
-    valid_attrs = [:title, :description, :assignee_id, :milestone_id, :target_branch]
+    valid_attrs = [:title, :description, :assignee_ids, :milestone_id, :target_branch]
 
     attrs_changed = valid_attrs.any? do |attr|
       issuable.previous_changes.include?(attr.to_s)
@@ -396,4 +408,8 @@ class IssuableBaseService < BaseService
   def ensure_milestone_available(issuable)
     issuable.milestone_id = nil unless issuable.milestone_available?
   end
+
+  def update_timestamp?(issuable)
+    issuable.changes.keys != ["relative_position"]
+  end
 end
