@@ -4,8 +4,8 @@ module Gitlab
   module SidekiqMiddleware
     class CorrelationInjector
       def call(worker_class, job, queue, redis_pool)
-        job[Gitlab::CorrelationId::LOG_KEY] ||=
-          Gitlab::CorrelationId.current_or_new_id
+        job[Labkit::Correlation::CorrelationId::LOG_KEY] ||=
+          Labkit::Correlation::CorrelationId.current_or_new_id
 
         yield
       end
